plot_rankings_correlation: Plot a scatter plot to compare two rankings.

plot_rankings_correlationR Documentation

Plot a scatter plot to compare two rankings.

Description

This function requires the package plotly.

Usage

plot_rankings_correlation(
  ranking_x,
  ranking_y,
  name_x,
  name_y,
  gene_sets = NULL,
  use_ranks = TRUE,
  use_sample = TRUE
)

Arguments

ranking_x

The ranking to be shown on the X axis.

ranking_y

The ranking to be shown on the Y axis.

name_x

Title of the X axis.

name_y

Title of the Y axis.

gene_sets

A named list of vectors of gene IDs to highlight. The names will be used to distinguish the sets and in the legend.

use_ranks

Show ranks instead of scores.

use_sample

Limit genes outside of the gene sets to a random sample.


johrpan/geposan documentation built on Feb. 28, 2025, 3:48 a.m.