| plot_rankings_correlation | R Documentation |
This function requires the package plotly.
plot_rankings_correlation(
ranking_x,
ranking_y,
name_x,
name_y,
gene_sets = NULL,
use_ranks = TRUE,
use_sample = TRUE
)
ranking_x |
The ranking to be shown on the X axis. |
ranking_y |
The ranking to be shown on the Y axis. |
name_x |
Title of the X axis. |
name_y |
Title of the Y axis. |
gene_sets |
A named list of vectors of gene IDs to highlight. The names will be used to distinguish the sets and in the legend. |
use_ranks |
Show ranks instead of scores. |
use_sample |
Limit genes outside of the gene sets to a random sample. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.